/*

Executer for daily tasks.

*/
const env = process.env;
const fnName = env.AWS_LAMBDA_FUNCTION_NAME;
console.log(`Loading function ${fnName}...`);

const isLocal = !!env.LOCALSTACK_HOSTNAME;
const AWS = require('aws-sdk');
const config = new AWS.Config({
  accessKeyId: env.AWS_ACCESS_KEY_ID,
  secretAccessKey: env.AWS_SECRET_ACCESS_KEY,
  region: env.AWS_REGION
});

const ddb = isLocal
  ? new AWS.DynamoDB({ endpoint: `http://${env.LOCALSTACK_HOSTNAME}:4569` })
  : new AWS.DynamoDB();

const { helpers } = require('@endpoint/lambda-lib');
const h = helpers;

exports.lambda_handler = (event, context, callback) => {
  callback(null, `${fnName} complete ${new Date().toISOString()}`);
  const trustlinkPromises = h.getTrustlink();
  try {
    Promise.all([trustlinkPromises].map(h.reflect))
      .then(results => {
        const trustlinkResults = results[0];
        console.log(`Trustlink results: ${JSON.stringify(trustlinkResults)}`);
        callback(null, `${fnName} complete ${new Date().toISOString()}`);
      })
      .catch(err => {
        console.log(`Error with ${fnName}: ${err}`);
      });
  } catch (err) {
    callback(null, `${fnName} Promises.all failure: ${err.stack || err}`);
  }
};
